@@ -95,6 +95,7 @@ gst_fakesrc_output_get_type (void)
     {FAKESRC_GET_ALWAYS_SUCEEDS, "8", "'_get' Always succeeds"},
     {0, NULL, NULL},
   };
+
   if (!fakesrc_output_type) {
     fakesrc_output_type =
         g_enum_register_static ("GstFakeSrcOutput", fakesrc_output);
@@ -112,6 +113,7 @@ gst_fakesrc_data_get_type (void)
     {FAKESRC_DATA_SUBBUFFER, "2", "Subbuffer data"},
     {0, NULL, NULL},
   };
+
   if (!fakesrc_data_type) {
     fakesrc_data_type = g_enum_register_static ("GstFakeSrcData", fakesrc_data);
   }
@@ -130,6 +132,7 @@ gst_fakesrc_sizetype_get_type (void)
         "Random sized buffers (sizemin <= size <= sizemax)"},
     {0, NULL, NULL},
   };
+
   if (!fakesrc_sizetype_type) {
     fakesrc_sizetype_type =
         g_enum_register_static ("GstFakeSrcSizeType", fakesrc_sizetype);
@@ -151,6 +154,7 @@ gst_fakesrc_filltype_get_type (void)
         "Fill buffers with pattern 0x00 -> 0xff that spans buffers"},
     {0, NULL, NULL},
   };
+
   if (!fakesrc_filltype_type) {
     fakesrc_filltype_type =
         g_enum_register_static ("GstFakeSrcFillType", fakesrc_filltype);
@@ -256,7 +260,7 @@ gst_fakesrc_class_init (GstFakeSrcClass * klass)
       g_signal_new ("handoff", G_TYPE_FROM_CLASS (klass), G_SIGNAL_RUN_LAST,
       G_STRUCT_OFFSET (GstFakeSrcClass, handoff), NULL, NULL,
       gst_marshal_VOID__POINTER_OBJECT, G_TYPE_NONE, 2,
-      GST_TYPE_BUFFER, GST_TYPE_PAD);
+      GST_TYPE_BUFFER | G_SIGNAL_TYPE_STATIC_SCOPE, GST_TYPE_PAD);
 
   gobject_class->set_property = GST_DEBUG_FUNCPTR (gst_fakesrc_set_property);
   gobject_class->get_property = GST_DEBUG_FUNCPTR (gst_fakesrc_get_property);
@@ -334,6 +338,7 @@ gst_fakesrc_get_formats (GstPad * pad)
     GST_FORMAT_DEFAULT,
     0,
   };
+
   return formats;
 }
 
@@ -347,6 +352,7 @@ gst_fakesrc_get_query_types (GstPad * pad)
     GST_QUERY_SEGMENT_END,
     0,
   };
+
   return types;
 }
 
@@ -384,6 +390,7 @@ gst_fakesrc_get_event_mask (GstPad * pad)
     {GST_EVENT_FLUSH, 0},
     {0, 0},
   };
+
   return masks;
 }
 
