@@ -329,7 +329,8 @@ gst_filesink_handle_event (GstPad * pad, GstEvent * event)
 
   filesink = GST_FILESINK (gst_pad_get_parent (pad));
 
-  g_return_val_if_fail (GST_FLAG_IS_SET (filesink, GST_FILESINK_OPEN), FALSE);
+  /* FIXME: should the event be unreferenced ? */
+  if (! (GST_FLAG_IS_SET (filesink, GST_FILESINK_OPEN))) return FALSE;
 
   type = event ? GST_EVENT_TYPE (event) : GST_EVENT_UNKNOWN;
 
