@@ -28,9 +28,13 @@
 #  include "config.h"
 #endif
 
+#include <glib.h>
+
 #include <stdlib.h>
 #include <string.h>
 
+gboolean __gst_in_valgrind (void);
+
 /*** debugging categories *****************************************************/
 
 #ifndef GST_DISABLE_GST_DEBUG
