@@ -116,26 +116,24 @@ struct _GstDebugCategory {
 /* You might want to define GST_FUNCTION in apps' configure script */
 
 #ifndef GST_FUNCTION
-#ifdef G_GNUC_PRETTY_FUNCTION
-#define GST_FUNCTION G_GNUC_PRETTY_FUNCTION
-#elif HAVE_FUNC
-#define GST_FUNCTION __func__
-#elif HAVE_PRETTY_FUNCTION
-#define GST_FUNCTION __PRETTY_FUNCTION__
-#elif HAVE_FUNCTION
-#define GST_FUNCTION __FUNCTION__
+#if defined (__GNUC__)
+#  define GST_FUNCTION     ((const char*) (__PRETTY_FUNCTION__))
+#elif defined (G_HAVE_ISO_VARARGS)
+#  define GST_FUNCTION     ((const char*) (__func__))
 #else
-#define GST_FUNCTION ""
+#  define GST_FUNCTION     ((const char*) ("???"))
 #endif
 #endif /* ifndef GST_FUNCTION */
 
+
+typedef struct _GstDebugMessage GstDebugMessage;
 typedef void (*GstLogFunction)	(GstDebugCategory *	category,
 				 GstDebugLevel		level,
 				 const gchar *		file,
 				 const gchar *		function,
 				 gint			line,
 				 GObject *		object,
-				 gchar *		message,
+				 GstDebugMessage *    	message,
 				 gpointer		data);
 
 /* Disable this subsystem if no varargs macro can be found. 
@@ -154,30 +152,34 @@ typedef void (*GstLogFunction)	(GstDebugCategory *	category,
 
 void		_gst_debug_init			(void);
 
+/* note we can't use G_GNUC_PRINTF (7, 8) because gcc chokes on %P, which
+ * we use for GST_PTR_FORMAT. */
 void		gst_debug_log			(GstDebugCategory *	category,
 						 GstDebugLevel		level,
 						 const gchar *		file,
 						 const gchar *		function,
 						 gint			line,
 						 GObject *		object,
-						 gchar *		format,
-						 ...)  G_GNUC_PRINTF (7, 8) G_GNUC_NO_INSTRUMENT;
+						 const gchar *		format,
+						 ...) G_GNUC_NO_INSTRUMENT;
 void		gst_debug_log_valist  		(GstDebugCategory *	category,
 						 GstDebugLevel		level,
 						 const gchar *		file,
 						 const gchar *		function,
 						 gint			line,
 						 GObject *		object,
-						 gchar *		format,
+						 const gchar *		format,
 						 va_list		args) G_GNUC_NO_INSTRUMENT;
 
+const gchar *	gst_debug_message_get		(GstDebugMessage *	message);
+
 void		gst_debug_log_default		(GstDebugCategory *	category,
 						 GstDebugLevel		level,
 						 const gchar *		file,
 						 const gchar *		function,
 						 gint			line,
 						 GObject *		object,
-						 gchar *		message,
+						 GstDebugMessage *    	message,
 						 gpointer		unused) G_GNUC_NO_INSTRUMENT;
 
 G_CONST_RETURN gchar *
@@ -203,24 +205,24 @@ void		gst_debug_unset_threshold_for_name (const gchar *	name);
 /**
  * GST_DEBUG_CATEGORY:
  * @cat: the category
- * 
- * Defines a GstCategory variable.
+ *
+ * Defines a GstDebugCategory variable.
  * This macro expands to nothing if debugging is disabled.
  */
 #define GST_DEBUG_CATEGORY(cat) GstDebugCategory *cat = NULL
 /**
  * GST_DEBUG_CATEGORY_EXTERN:
  * @cat: the category
- * 
- * Defines an extern GstCategory variable. Use in header files.
+ *
+ * Declares a GstDebugCategory variable as extern. Use in header files.
  * This macro expands to nothing if debugging is disabled.
  */
 #define GST_DEBUG_CATEGORY_EXTERN(cat) extern GstDebugCategory *cat
 /**
  * GST_DEBUG_CATEGORY_STATIC:
  * @cat: the category
- * 
- * Defines a static GstCategory variable.
+ *
+ * Defines a static GstDebugCategory variable.
  * This macro expands to nothing if debugging is disabled.
  */
 #define GST_DEBUG_CATEGORY_STATIC(cat) static GstDebugCategory *cat = NULL
@@ -230,26 +232,29 @@ GstDebugCategory *_gst_debug_category_new	(gchar *		name,
 						 gchar *		description);
 /**
  * GST_DEBUG_CATEGORY_INIT:
- * @cat: the category to initialize
- * @name: the name of the category
- * @color: the colors to use for a color representation or 0 for no color
- * @description: optional description of the category
- * 
- * Creates a new #GstDebugCategory cat with the given properties and sets it to
+ * @cat: the category to initialize.
+ * @name: the name of the category.
+ * @color: the colors to use for a color representation or 0 for no color.
+ * @description: optional description of the category.
+ *
+ * Initializes a new #GstDebugCategory with the given properties and set to
  * the default threshold.
- * This macro expands to nothing if debugging is disabled.
+ *
  * <note>
  * <para>
- * When naming your category, please follow the following definitions to ensure
+ * This macro expands to nothing if debugging is disabled.
+ * </para>
+ * <para>
+ * When naming your category, please follow the following conventions to ensure
  * that the pattern matching for categories works as expected. It is not
  * earth-shattering if you don't follow these conventions, but it would be nice
  * for everyone.
  * </para>
  * <para>
- * If you define a category for a plugin or a feature of it, name the category 
- * like the feature. So if you wanted to write a "filesrc" element, you would 
+ * If you define a category for a plugin or a feature of it, name the category
+ * like the feature. So if you wanted to write a "filesrc" element, you would
  * name the category "filesrc". Use lowercase letters only.
- * If you define more than one category for the same element, append an 
+ * If you define more than one category for the same element, append an
  * underscore and an identifier to your categories, like this: "filesrc_cache"
  * </para>
  * <para>
@@ -264,6 +269,7 @@ GstDebugCategory *_gst_debug_category_new	(gchar *		name,
   if (cat == NULL)								\
     cat = _gst_debug_category_new (name,color,description);			\
 }G_STMT_END
+
 void		gst_debug_category_free		(GstDebugCategory *	category);
 void		gst_debug_category_set_threshold (GstDebugCategory *	category,
 						 GstDebugLevel		level);
@@ -393,7 +399,6 @@ G_CONST_RETURN gchar*
 #ifdef __GNUC__
 #  pragma GCC poison gst_debug_log
 #  pragma GCC poison gst_debug_log_valist
-#  pragma GCC poison gst_debug_log_default
 #  pragma GCC poison _gst_debug_category_new
 #endif
 
@@ -516,6 +521,14 @@ G_CONST_RETURN gchar*
 
 void gst_debug_print_stack_trace (void);
 
+/* timestamp debugging macros */
+#define GST_TIME_FORMAT "u:%02u:%02u:%09u"
+#define GST_TIME_ARGS(t) \
+	(guint) (t / (GST_SECOND * 60 * 60)), \
+	(guint) ((t / (GST_SECOND * 60)) % 60), \
+	(guint) ((t / GST_SECOND) % 60), \
+	(guint) (t % GST_SECOND)
+
 G_END_DECLS
 
 #endif /* __GSTINFO_H__ */
