@@ -381,7 +381,7 @@ GList*			gst_pad_get_ghost_pad_list		(GstPad *pad);
 
 GstPadTemplate*		gst_pad_get_pad_template		(GstPad *pad);
 
-void			gst_pad_set_bufferalloc_function		(GstPad *pad, GstPadBufferAllocFunction bufferalloc);
+void			gst_pad_set_bufferalloc_function		(GstPad *pad, GstPadBufferAllocFunction bufalloc);
 GstBuffer*		gst_pad_alloc_buffer			(GstPad *pad, guint64 offset, gint size);
 
 /* data passing setup functions */
@@ -443,10 +443,15 @@ void			gst_pad_push				(GstPad *pad, GstData *data);
 GstData*		gst_pad_pull				(GstPad *pad);
 gboolean		gst_pad_send_event			(GstPad *pad, GstEvent *event);
 gboolean		gst_pad_event_default			(GstPad *pad, GstEvent *event);
+#ifndef GST_DISABLE_DEPRECATED
 GstPad*			gst_pad_selectv				(GList *padlist);
 GstPad*			gst_pad_select				(GstPad *pad, ...);
 GstPad*			gst_pad_select_valist			(GstPad *pad, va_list varargs);
-
+#endif
+/* FIXME 0.9: rename to _select? Otherwise rename SchedulerClass pointer */
+GstData *		gst_pad_collectv			(GstPad **selected, const GList *padlist);
+GstData *		gst_pad_collect				(GstPad **selected, GstPad *pad, ...);
+GstData *		gst_pad_collect_valist			(GstPad **selected, GstPad *pad, va_list varargs);
 
 /* convert/query/format functions */
 void			gst_pad_set_formats_function		(GstPad *pad, 
@@ -504,7 +509,7 @@ GstPadTemplate*		gst_pad_template_new			(const gchar *name_template,
 		                                        	 GstPadDirection direction, GstPadPresence presence,
 								 GstCaps *caps);
 
-GstPadTemplate *	gst_static_pad_template_get             (GstStaticPadTemplate *templ);
+GstPadTemplate *	gst_static_pad_template_get             (GstStaticPadTemplate *pad_template);
 const GstCaps*		gst_pad_template_get_caps		(GstPadTemplate *templ);
 const GstCaps*		gst_pad_template_get_caps_by_name	(GstPadTemplate *templ, const gchar *name);
 
