@@ -277,10 +277,10 @@ static void _gst_plugin_fault_handler_setup ();
 
 /**
  * gst_plugin_load_file:
- * @plugin: The plugin to load
- * @error: Pointer to a NULL-valued GError.
+ * @filename: the plugin filename to load
+ * @error: pointer to a NULL-valued GError
  *
- * Load the given plugin.
+ * Loads the given plugin.
  *
  * Returns: a new GstPlugin or NULL, if an error occurred.
  */
@@ -330,7 +330,7 @@ gst_plugin_load_file (const gchar * filename, GError ** error)
       } else {
         free_plugin = FALSE;
         if (gst_plugin_is_loaded (plugin)) {
-          if (strcmp (plugin->filename, filename) != 0) {
+          if (plugin->filename && strcmp (plugin->filename, filename) != 0) {
             GST_WARNING
                 ("plugin %p from file \"%s\" with same name %s is already "
                 "loaded, aborting loading of \"%s\"", plugin, plugin->filename,
