@@ -26,6 +26,7 @@
 GST_DEBUG_CATEGORY (cat);
 GST_DEBUG_CATEGORY_STATIC (cat_static);
 
+#ifndef GST_DISABLE_GST_DEBUG
 static const gchar *lines[] = {
   "--gst-debug-disable",
   "--gst-debug-no-color",
@@ -41,27 +42,33 @@ debug_not_reached (GstDebugCategory * category, GstDebugLevel level,
 {
   g_assert_not_reached ();
 }
+#endif
 
 gint
 main (gint argc, gchar * argv[])
 {
   if (argc == 1) {
     /* this is the main run that calls the others */
-    gint i, runs, exit;
-    gchar *command;
 
     unsetenv ("GST_DEBUG");
     gst_init (&argc, &argv);
-    runs = G_N_ELEMENTS (lines);
-    for (i = 0; i < runs; i++) {
-      command = g_strdup_printf ("%s %s %d", argv[0], lines[i], i);
-      g_print ("running \"%s\"\n", command);
-      g_assert (g_spawn_command_line_sync (command, NULL, NULL, &exit,
-              NULL) == TRUE);
-      g_assert (exit == 0);
-      g_print ("\"%s\" worked as expected.\n", command);
-      g_free (command);
+#ifndef GST_DISABLE_GST_DEBUG
+    {
+      gint i, runs, exit;
+      gchar *command;
+
+      runs = G_N_ELEMENTS (lines);
+      for (i = 0; i < runs; i++) {
+        command = g_strdup_printf ("%s %s %d", argv[0], lines[i], i);
+        g_print ("running \"%s\"\n", command);
+        g_assert (g_spawn_command_line_sync (command, NULL, NULL, &exit,
+                NULL) == TRUE);
+        g_assert (exit == 0);
+        g_print ("\"%s\" worked as expected.\n", command);
+        g_free (command);
+      }
     }
+#endif
 
     return 0;
   } else {
@@ -71,13 +78,17 @@ main (gint argc, gchar * argv[])
           ("something funny happened to the command line arguments, aborting.\n");
       return 1;
     }
-    gst_debug_remove_log_function (gst_debug_log_default);
+#ifndef GST_DISABLE_GST_DEBUG
+    g_assert (gst_debug_remove_log_function (gst_debug_log_default) == 1);
+#endif
     GST_DEBUG_CATEGORY_INIT (cat, "cat", 0, "non-static category");
     GST_DEBUG_CATEGORY_INIT (cat_static, "cat_static", 0, "static category");
     switch (argv[1][0]) {
       case '0':
         g_assert (gst_debug_is_active () == FALSE);
+#ifndef GST_DISABLE_GST_DEBUG
         gst_debug_add_log_function (debug_not_reached, NULL);
+#endif
         GST_ERROR ("This will not be seen");
         return 0;
       case '1':
